@@ -1,9 +1,10 @@
 use strict;
 use warnings;
+no if "$]" >= 5.031008, feature => 'indirect';
 package {{ $name }};
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: ...
 # KEYWORDS: ...
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
 our $VERSION = '{{ $dist->version }}';
 
@@ -22,7 +23,8 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        ...
+        ...,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -60,14 +62,6 @@ SYNOPSIS
 
 ...
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name={{ $dist->name }}>
-(or L<bug-{{ $dist->name }}@rt.cpan.org|mailto:bug-{{ $dist->name }}@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 ACKNOWLEDGEMENTS
 
 ...
